#ifndef QTAGSELECTORDIALOG_H
#define QTAGSELECTORDIALOG_H

#include <QtGui/QDialog>
#include "ui_QTagSelectorDialog.h"
#include "QvernoteAPI.h"
#include <QGridLayout>

using namespace qvernote::api;

class QTagSelectorDialog : public QDialog
{
    Q_OBJECT

public:
    QTagSelectorDialog(QvernoteAPI* hEvernote, const Note& note, QWidget *parent = 0);
    ~QTagSelectorDialog();

    void loadTagsIntoView();
    void addTag(Tag& tag);

public slots:
	void addNewTag();

private:
    Ui::QTagSelectorDialogClass ui;
    vector<string> m_vTagNames;
    vector<string> tagGuids;
    QvernoteAPI* m_hEvernote;
    QRect geom;
};

#endif // QTAGSELECTORDIALOG_H
